@@ -20,12 +20,12 @@ DEFAULT_FONT_SIZE = 10
 #UI_GTK = 2
 UI_WX = 3
 #UI_KDE = 4
-UI_QT4 = 5
-UI_KDE4 = 6
-UI_PYSIDE = 7
+#UI_QT4 = 5
+#UI_KDE4 = 6
+#UI_PYSIDE = 7
 UI_QT5 = 8
 UI_PYSIDE2 = 9
-UI_WEB = 10
+#UI_WEB = 10
 
 # message box types
 MBOX_INFO = 0
@@ -68,6 +68,7 @@ SIGNAL_ACTIVATED = 10  # widget has received focus
 SIGNAL_CLICKED = 101  # widget has been clicked
 SIGNAL_TOGGLED = 102  # on/off widget has been toggled
 SIGNAL_SELECTED = 151  # item in widget has been selected; handler must take index param
+SIGNAL_BUTTONSELECTED = 156  # item in button group has been selected; handler must take index param
 SIGNAL_LISTVIEWSELECTED = 161  # list view item has changed; handler must take item param
 SIGNAL_LISTBOXSELECTED = 165  # list box item has changed; handler must take item param
 SIGNAL_CELLSELECTED = 171  # table current cell has changed; handler must take row, col params
