@@ -21,10 +21,10 @@ from .app import PWxWidget, PWxActionMixin, scaled_bitmap
 
 class PWxButtonMixin(PWxWidget):
     
-    _align = False  # used by panel to determine placement
+    fn_get_caption = 'GetLabel'
+    fn_set_caption = 'SetLabel'
     
-    def set_caption(self, caption):
-        self.SetLabel(caption)
+    _align = False  # used by panel to determine placement
     
     iconfactor = 0.5
     
